@@ -30,6 +30,9 @@ import android.media.AudioManager;
 import android.os.Handler;
 import android.os.IBinder;
 import android.os.Looper;
+import android.support.v7.app.AppCompatDelegate;
+
+import com.bumptech.glide.Glide;
 
 import java.util.HashMap;
 import java.util.Map;
@@ -127,7 +130,8 @@ public abstract class RingApplication extends Application {
     @Override
     public void onLowMemory() {
         super.onLowMemory();
-        AvatarFactory.onLowMemory();
+        AvatarFactory.clearCache();
+        Glide.get(this).clearMemory();
     }
 
     private void setDefaultUncaughtExceptionHandler() {
@@ -210,6 +214,9 @@ public abstract class RingApplication extends Application {
 
         sInstance = this;
 
+        if (android.os.Build.VERSION.SDK_INT < android.os.Build.VERSION_CODES.LOLLIPOP)
+            AppCompatDelegate.setCompatVectorFromResourcesEnabled(true);
+
         setDefaultUncaughtExceptionHandler();
 
         mPermissionsBeingAsked = new HashMap<>();
