@@ -88,7 +88,6 @@ public class ConversationFacade {
     @Inject
     PreferencesService mPreferencesService;
 
-    private Account mConversations = null;
     private final CompositeDisposable mDisposableBag = new CompositeDisposable();
 
     private final Observable<Account> currentAccountSubject;
@@ -108,13 +107,27 @@ public class ConversationFacade {
                 .subscribe(this::onCallStateChange));
 
         mDisposableBag.add(currentAccountSubject
-                .subscribe(account -> {
-                    Log.d(TAG, "refreshConversations() " + account);
-                    mConversations = account;
-                    for (Conversation conversation : account.getConversations()) {
-                        mPresenceService.subscribeBuddy(account.getAccountID(), conversation.getContact().getPrimaryUri().getRawUriString(), true);
-                    }
-                }));
+                .switchMap(a -> Observable
+                        .merge(a.getConversationsSubject(), a.getPendingSubject())
+                        .doOnNext(c -> {
+                            for (Conversation conversation : c) {
+                                Uri id = conversation.getContact().getPrimaryUri();
+                                mPresenceService.subscribeBuddy(a.getAccountID(), id.getRawUriString(), true);
+                                mContactService.loadContactData(conversation.getContact());
+                                mAccountService.lookupAddress(a.getAccountID(), "", id.getRawRingId());
+                            }
+                        }))
+                .subscribeOn(Schedulers.computation())
+                .subscribe());
+
+        mDisposableBag.add(currentAccountSubject
+                .switchMap(a -> a.getPendingSubject()
+                        .doOnNext(p -> mNotificationService.showIncomingTrustRequestNotification(a)))
+                .subscribe());
+
+        mDisposableBag.add(mAccountService.getIncomingRequests()
+                .switchMapSingle(r -> getAccountSubject(r.getAccountId()))
+                .subscribe(a -> mNotificationService.showIncomingTrustRequestNotification(a)));
 
         mDisposableBag.add(mAccountService
                 .getIncomingMessages()
@@ -133,6 +146,7 @@ public class ConversationFacade {
                         conv.updateTextMessage(txt);
                     }
                 }));
+
         mDisposableBag.add(mAccountService.getDataTransfers().subscribe(this::handleDataTransferEvent));
     }
 
@@ -294,29 +308,23 @@ public class ConversationFacade {
                 });
     }
 
-    public void updateTextNotifications() {
+    public void updateTextNotifications(String accountId, List<Conversation> conversations) {
         Log.d(TAG, "updateTextNotifications()");
 
-        for (Conversation conversation : mConversations.getConversations()) {
-            TreeMap<Long, TextMessage> texts = conversation.getUnreadTextMessages();
-
-            CallContact contact = conversation.getContact();
-            if (texts.isEmpty() || conversation.isVisible()) {
-                mNotificationService.cancelTextNotification(contact.getPrimaryUri());
-                continue;
-            }
-            if (texts.lastEntry().getValue().isNotified()) {
-                continue;
-            }
-            mNotificationService.showTextNotification(contact, conversation, texts);
+        for (Conversation conversation : conversations) {
+            mNotificationService.showTextNotification(accountId, conversation);
         }
     }
 
-    private void parseNewMessage(TextMessage txt) {
+    private void parseNewMessage(final TextMessage txt) {
         if (txt.isRead()) {
             mHistoryService.updateTextMessage(new HistoryText(txt)).subscribe();
         }
-        updateTextNotifications();
+        getAccountSubject(txt.getAccount())
+                .flatMapObservable(Account::getConversationsSubject)
+                .firstOrError()
+                .subscribeOn(Schedulers.computation())
+                .subscribe(c -> updateTextNotifications(txt.getAccount(), c));
     }
 
     public void acceptRequest(String accountId, Uri contactUri) {
@@ -349,7 +357,8 @@ public class ConversationFacade {
                 mAccountService.acceptFileTransfer(transfer);
             }
         }
-        mNotificationService.showFileTransferNotification(transfer, conversation.getContact());
+        if (!conversation.isVisible())
+            mNotificationService.showFileTransferNotification(transfer, conversation.getContact());
     }
 
     private void onCallStateChange(SipCall call) {
@@ -399,6 +408,9 @@ public class ConversationFacade {
                 HistoryCall historyCall = new HistoryCall(call);
                 mHistoryService.insertNewEntry(historyCall).subscribe();
                 conversation.addHistoryCall(historyCall);
+                if (historyCall.isIncoming() && historyCall.isMissed()) {
+                    mNotificationService.showMissedCallNotification(call);
+                }
                 account.updated(conversation);
             }
             mCallService.removeCallForId(call.getCallId());
@@ -418,4 +430,11 @@ public class ConversationFacade {
         }
         return mCallService.placeCall(rawId, number, video);
     }
+
+    public void cancelFileTransfer(long id) {
+        mAccountService.cancelDataTransfer(id);
+        DataTransfer transfer = mAccountService.getDataTransfer(id);
+        if (transfer != null)
+            deleteFile(transfer);
+    }
 }
\ No newline at end of file
