@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2016 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2018 Savoir-faire Linux Inc.
  *
  *  Author: Alexandre Lision <alexandre.lision@savoirfairelinux.com>
  *  Author: Adrien Béraud <adrien.beraud@savoirfairelinux.com>
@@ -22,20 +22,28 @@ package cx.ring.model;
 
 import java.lang.ref.WeakReference;
 import java.util.ArrayList;
+import java.util.Date;
+
+import cx.ring.utils.StringUtils;
+import cx.ring.utils.Tuple;
+import ezvcard.VCard;
+import io.reactivex.Observable;
+import io.reactivex.subjects.PublishSubject;
+import io.reactivex.subjects.Subject;
 
 public class CallContact {
-
+    protected static final String TAG = CallContact.class.getSimpleName();
 
     public static final int UNKNOWN_ID = -1;
     public static final int DEFAULT_ID = 0;
-    public static final String PREFIX_RING = "ring:";
+    public static final String PREFIX_RING = Uri.RING_URI_SCHEME;
 
     public enum Status {BANNED, REQUEST_SENT, CONFIRMED, NO_REQUEST}
 
     private long mId;
     private String mKey;
     private String mDisplayName;
-    private String mUsername;
+    private String mUsername = null;
     private long mPhotoId;
     private final ArrayList<Phone> mPhones;
     private boolean isUser;
@@ -43,6 +51,17 @@ public class CallContact {
     private boolean stared = false;
     private boolean isFromSystem = false;
     private Status mStatus = Status.NO_REQUEST;
+    private Date mAddedDate = null;
+    private boolean mOnline = false;
+
+    public boolean detailsLoaded = false;
+    public VCard vcard = null;
+
+    private Subject<CallContact> mContactUpdates = PublishSubject.create();
+
+    public Observable<CallContact> getUpdates() {
+        return mContactUpdates;
+    }
 
     public CallContact(long cID) {
         this(cID, null, null, UNKNOWN_ID);
@@ -56,7 +75,6 @@ public class CallContact {
         mId = cID;
         mKey = k;
         mDisplayName = displayName;
-        mUsername = displayName;
         mPhones = p;
         mPhotoId = photoID;
         isUser = user;
@@ -68,14 +86,14 @@ public class CallContact {
     public static CallContact buildUnknown(Uri to) {
         ArrayList<Phone> phones = new ArrayList<>();
         phones.add(new Phone(to, 0));
-        return new CallContact(UNKNOWN_ID, null, to.getRawUriString(), 0, phones, "", false);
+        return new CallContact(UNKNOWN_ID, null, null, 0, phones, "", false);
     }
 
     public static CallContact buildUnknown(String to) {
         ArrayList<Phone> phones = new ArrayList<>();
         phones.add(new Phone(to, 0));
 
-        return new CallContact(UNKNOWN_ID, null, to, 0, phones, "", false);
+        return new CallContact(UNKNOWN_ID, null, null, 0, phones, "", false);
     }
 
     public static CallContact buildUnknown(String to, String address) {
@@ -95,10 +113,24 @@ public class CallContact {
         return new CallContact(UNKNOWN_ID, null, to, 0, phones, "", false);
     }
 
-    public static CallContact buildRingContact(Uri ringId) {
-        ArrayList<Phone> phones = new ArrayList<>();
-        phones.add(new Phone(ringId, 0));
-        return new CallContact(UNKNOWN_ID, null, null, 0, phones, "", false);
+    public static CallContact buildRingContact(Uri ringId, String username) {
+        CallContact contact = buildUnknown(ringId);
+        contact.setUsername(username);
+        return contact;
+    }
+
+    public boolean matches(String query) {
+        return (mDisplayName != null && mDisplayName.contains(query))
+                || (mUsername != null && mUsername.contains(query))
+                || (getPrimaryNumber().contains(query));
+    }
+
+    public boolean isOnline() {
+        return mOnline;
+    }
+
+    public void setOnline(boolean present) {
+        mOnline = present;
     }
 
     public void setContactInfos(String k, String displayName, long photo_id) {
@@ -117,7 +149,7 @@ public class CallContact {
     }
 
     public ArrayList<String> getIds() {
-        ArrayList<String> ret = new ArrayList<>(1 + mPhones.size());
+        ArrayList<String> ret = new ArrayList<>(mPhones.size() + (mId == UNKNOWN_ID ? 0 : 1));
         if (mId != UNKNOWN_ID)
             ret.add("c:" + Long.toHexString(mId));
         for (Phone p : mPhones)
@@ -140,11 +172,7 @@ public class CallContact {
     }
 
     public String getDisplayName() {
-        if (mDisplayName != null && !mDisplayName.isEmpty())
-            return mDisplayName;
-        if (!mPhones.isEmpty())
-            return mPhones.get(0).getNumber().getRawUriString();
-        return "";
+        return !StringUtils.isEmpty(mDisplayName) ? mDisplayName : getRingUsername();
     }
 
     public long getPhotoId() {
@@ -170,7 +198,7 @@ public class CallContact {
 
     @Override
     public String toString() {
-        return mDisplayName;
+        return getRingUsername();
     }
 
     public void setId(long id) {
@@ -181,6 +209,13 @@ public class CallContact {
         return mKey;
     }
 
+    public String getPrimaryNumber() {
+        return getPrimaryUri().getRawRingId();
+    }
+    public Uri getPrimaryUri() {
+        return getPhones().get(0).getNumber();
+    }
+
     public void setStared() {
         this.stared = true;
     }
@@ -238,6 +273,13 @@ public class CallContact {
         isFromSystem = fromSystem;
     }
 
+    public void setAddedDate(Date addedDate) {
+        mAddedDate = addedDate;
+    }
+    public Date getAddedDate() {
+        return mAddedDate;
+    }
+
     /**
      * A contact is Unknown when his name == his phone number
      *
@@ -247,19 +289,17 @@ public class CallContact {
         return mDisplayName == null || mDisplayName.contentEquals(mPhones.get(0).getNumber().getRawUriString());
     }
 
-    public void resetDisplayName() {
-        mDisplayName = null;
-    }
-
     public void setDisplayName(String displayName) {
         mDisplayName = displayName;
     }
 
     public String getRingUsername() {
-        if (mUsername != null && !mUsername.isEmpty()) {
+        if (!StringUtils.isEmpty(mUsername)) {
             return mUsername;
+        } else if (!mPhones.isEmpty()) {
+            return getPrimaryUri().getRawUriString();
         } else {
-            return mPhones.get(0).getNumber().getRawUriString();
+            return "";
         }
     }
 
@@ -267,11 +307,52 @@ public class CallContact {
         return mUsername;
     }
 
-    public void setUsername(String name) {
-        mUsername = name;
+    public boolean setUsername(String name) {
+        if (!name.equals(mUsername)) {
+            mUsername = name;
+            mContactUpdates.onNext(this);
+            return true;
+        }
+        return false;
+    }
+
+    private static Tuple<String, byte[]> readVCardContactData(VCard vcard) {
+        String contactName = null;
+        byte[] photo = null;
+        if (vcard != null) {
+            if (!vcard.getPhotos().isEmpty()) {
+                try {
+                    photo = vcard.getPhotos().get(0).getData();
+                } catch (Exception e) {
+                    photo = null;
+                }
+            }
+            if (vcard.getFormattedName() != null) {
+                if (!StringUtils.isEmpty(vcard.getFormattedName().getValue())) {
+                    contactName = vcard.getFormattedName().getValue();
+                }
+            }
+        }
+        return new Tuple<>(contactName, photo);
+    }
+
+    public void setProfile(String name, byte[] photo) {
+        if (!StringUtils.isEmpty(name) && !name.startsWith(Uri.RING_URI_SCHEME)) {
+            setDisplayName(name);
+        }
+        if (photo != null && photo.length > 0) {
+            setPhoto(photo);
+        }
+        detailsLoaded = true;
+        mContactUpdates.onNext(this);
+    }
+
+    public void setVCardProfile(VCard vcard) {
+        this.vcard = vcard;
+        Tuple<String, byte[]> info = readVCardContactData(vcard);
+        setProfile(info.first, info.second);
     }
 
-    //region Equals
     @Override
     public boolean equals(Object o) {
         if (o == this) {
@@ -284,10 +365,4 @@ public class CallContact {
         return contact.getId() == this.getId() && contact.getDisplayName().equals(this.getDisplayName());
     }
 
-    @Override
-    public int hashCode() {
-        return super.hashCode();
-    }
-    //endregion
-
 }
