@@ -30,3 +30,15 @@
 #import "RegistrationResponse.h"
 #import "NameRegistrationResponse.h"
 #import "MessagesAdapter.h"
+#import "Chameleon/Chameleon.h"
+#import "ContactsAdapter.h"
+#import "PresenceAdapter.h"
+#import "VideoAdapter.h"
+#import "AudioAdapter.h"
+#import <CommonCrypto/CommonCrypto.h>
+#import <Contacts/Contacts.h>
+#import "CallsAdapter.h"
+#import <PushKit/PushKit.h>
+#import <UserNotifications/UserNotifications.h>
+#import <GSKStretchyHeaderView/GSKStretchyHeaderView.h>
+#import "DataTransferAdapter.h"
