@@ -39,6 +39,8 @@
 #import <api/conversation.h>
 #import <api/contactmodel.h>
 #import <api/contact.h>
+#import <api/datatransfermodel.h>
+#import <media/recordingmodel.h>
 
 // Ring
 #import "AppDelegate.h"
@@ -52,6 +54,7 @@
 #import "views/NSColor+RingTheme.h"
 #import "views/BackgroundView.h"
 #import "ChooseAccountVC.h"
+#import "utils.h"
 
 @interface RingWindowController () <MigrateRingAccountsDelegate, NSToolbarDelegate>
 
@@ -63,6 +66,7 @@
 
     __unsafe_unretained IBOutlet NSLayoutConstraint* centerYQRCodeConstraint;
     __unsafe_unretained IBOutlet NSLayoutConstraint* centerYWelcomeContainerConstraint;
+    IBOutlet NSLayoutConstraint* ringLabelTrailingConstraint;
     __unsafe_unretained IBOutlet NSView* welcomeContainer;
     __unsafe_unretained IBOutlet NSView* callView;
     __unsafe_unretained IBOutlet NSTextField* ringIDLabel;
@@ -75,7 +79,8 @@
     IBOutlet SmartViewVC* smartViewVC;
 
     CurrentCallVC* currentCallVC;
-    ConversationVC* offlineVC;
+    ConversationVC* conversationVC;
+
     // toolbar menu items
     ChooseAccountVC* chooseAccountVC;
 }
@@ -93,18 +98,18 @@ NSString* const kChangeAccountToolBarItemIdentifier  = @"ChangeAccountToolBarIte
     lrc_ = std::make_unique<lrc::api::Lrc>();
 
     currentCallVC = [[CurrentCallVC alloc] initWithNibName:@"CurrentCall" bundle:nil];
-    offlineVC = [[ConversationVC alloc] initWithNibName:@"Conversation" bundle:nil delegate:self];
+    conversationVC = [[ConversationVC alloc] initWithNibName:@"Conversation" bundle:nil delegate:self];
     // toolbar items
     chooseAccountVC = [[ChooseAccountVC alloc] initWithNibName:@"ChooseAccount" bundle:nil model:&(lrc_->getAccountModel()) delegate:self];
     [callView setAutoresizingMask:NSViewWidthSizable | NSViewHeightSizable];
     [[currentCallVC view] setAutoresizingMask:NSViewWidthSizable | NSViewHeightSizable];
-    [[offlineVC view] setAutoresizingMask:NSViewWidthSizable | NSViewHeightSizable];
+    [[conversationVC view] setAutoresizingMask:NSViewWidthSizable | NSViewHeightSizable];
 
     [callView addSubview:[currentCallVC view] positioned:NSWindowAbove relativeTo:nil];
-    [callView addSubview:[offlineVC view] positioned:NSWindowAbove relativeTo:nil];
+    [callView addSubview:[conversationVC view] positioned:NSWindowAbove relativeTo:nil];
 
     [currentCallVC initFrame];
-    [offlineVC initFrame];
+    [conversationVC initFrame];
     @try {
         [smartViewVC setConversationModel: [chooseAccountVC selectedAccount].conversationModel.get()];
     }
@@ -121,6 +126,17 @@ NSString* const kChangeAccountToolBarItemIdentifier  = @"ChangeAccountToolBarIte
     NSToolbar *toolbar = self.window.toolbar;
     toolbar.delegate = self;
     [toolbar insertItemWithItemIdentifier:kChangeAccountToolBarItemIdentifier atIndex:1];
+    // set download folder (default - 'Documents')
+    NSString* path = [[NSUserDefaults standardUserDefaults] stringForKey:Preferences::DownloadFolder];
+    if (!path || path.length == 0) {
+        NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
+        path = [[paths objectAtIndex:0] stringByAppendingString:@"/"];
+    }
+    lrc_->getDataTransferModel().downloadDirectory = std::string([path UTF8String]);
+    if(appSandboxed()) {
+        NSArray *paths = NSSearchPathForDirectoriesInDomains(NSDocumentDirectory, NSUserDomainMask, YES);
+        Media::RecordingModel::instance().setRecordPath(QString::fromNSString([paths objectAtIndex:0]));
+    }
 }
 
 - (void) connect
@@ -139,8 +155,8 @@ NSString* const kChangeAccountToolBarItemIdentifier  = @"ChangeAccountToolBarIte
                                           conversation:convInfo.uid
                                                account:accInfo];
                          [smartViewVC selectConversation: convInfo model:accInfo->conversationModel.get()];
-                         [currentCallVC animateIn];
-                         [offlineVC animateOut];
+                         [currentCallVC showWithAnimation:false];
+                         [conversationVC hideWithAnimation:false];
                      });
 
     QObject::connect(&lrc_->getBehaviorController(),
@@ -157,8 +173,8 @@ NSString* const kChangeAccountToolBarItemIdentifier  = @"ChangeAccountToolBarIte
                                           conversation:convInfo.uid
                                                account:accInfo];
                          [smartViewVC selectConversation: convInfo model:accInfo->conversationModel.get()];
-                         [currentCallVC animateIn];
-                         [offlineVC animateOut];
+                         [currentCallVC showWithAnimation:false];
+                         [conversationVC hideWithAnimation:false];
                      });
 
     QObject::connect(&lrc_->getBehaviorController(),
@@ -166,10 +182,10 @@ NSString* const kChangeAccountToolBarItemIdentifier  = @"ChangeAccountToolBarIte
                      [self](const std::string& accountId,
                             const lrc::api::conversation::Info& convInfo){
                          auto& accInfo = lrc_->getAccountModel().getAccountInfo(accountId);
-                         [offlineVC setConversationUid:convInfo.uid model:accInfo.conversationModel.get()];
+                         [conversationVC setConversationUid:convInfo.uid model:accInfo.conversationModel.get()];
                          [smartViewVC selectConversation: convInfo model:accInfo.conversationModel.get()];
-                         [offlineVC animateIn];
-                         [currentCallVC animateOut];
+                         [conversationVC showWithAnimation:false];
+                         [currentCallVC hideWithAnimation:false];
                      });
 }
 
@@ -185,10 +201,13 @@ NSString* const kChangeAccountToolBarItemIdentifier  = @"ChangeAccountToolBarIte
         [ringIDLabel setStringValue:@""];
 
         if(account.profileInfo.type != lrc::api::profile::Type::RING) {
-            self.hideRingID = YES;
+            self.notRingAccount = YES;
+            self.isSIPAccount = YES;
             return;
         }
-        self.hideRingID = NO;
+        self.isSIPAccount = NO;
+        self.notRingAccount = NO;
+        [ringLabelTrailingConstraint setActive:YES];
         auto& registeredName = account.registeredName;
         auto& ringID = account.profileInfo.uri;
         NSString* uriToDisplay = nullptr;
@@ -202,7 +221,9 @@ NSString* const kChangeAccountToolBarItemIdentifier  = @"ChangeAccountToolBarIte
     }
     @catch (NSException *ex) {
         NSLog(@"Caught exception %@: %@", [ex name], [ex reason]);
-        self.hideRingID = NO;
+        self.notRingAccount = YES;
+        self.isSIPAccount = NO;
+        [ringLabelTrailingConstraint setActive:NO];
         [ringIDLabel setStringValue:NSLocalizedString(@"No account available", @"Displayed as RingID when no accounts are available for selection")];
     }
 }
@@ -303,7 +324,11 @@ NSString* const kChangeAccountToolBarItemIdentifier  = @"ChangeAccountToolBarIte
 
 - (IBAction)openPreferences:(id)sender
 {
-    preferencesWC = [[PreferencesWC alloc] initWithWindowNibName:@"PreferencesWindow"];
+    if (preferencesWC) {
+        [preferencesWC.window orderFront:preferencesWC.window];
+        return;
+    }
+    preferencesWC = [[PreferencesWC alloc] initWithNibName:@"PreferencesWindow" bundle: nil model:&(lrc_->getDataTransferModel())];
     [preferencesWC.window makeKeyAndOrderFront:preferencesWC.window];
 }
 
@@ -371,14 +396,22 @@ NSString* const kChangeAccountToolBarItemIdentifier  = @"ChangeAccountToolBarIte
 {
     // If the selected account has been changed, we close any open panel
     if ([smartViewVC setConversationModel:accInfo.conversationModel.get()]) {
-        [currentCallVC animateOut];
-        [offlineVC animateOut];
+        [currentCallVC hideWithAnimation:false];
+        [conversationVC hideWithAnimation:false];
     }
 
     // Welcome view informations are also updated
     [self updateRingID];
 }
 
+-(void)allAccountsDeleted
+{
+    [smartViewVC clearConversationModel];
+    [currentCallVC hideWithAnimation:false];
+    [conversationVC hideWithAnimation:false];
+    [self updateRingID];
+}
+
 -(void)rightPanelClosed
 {
     [smartViewVC deselect];
@@ -390,8 +423,8 @@ NSString* const kChangeAccountToolBarItemIdentifier  = @"ChangeAccountToolBarIte
 }
 
 -(void) listTypeChanged {
-    [offlineVC animateOut];
-    [currentCallVC animateOut];
+    [conversationVC hideWithAnimation:false];
+    [currentCallVC hideWithAnimation:false];
 }
 
 #pragma mark - NSToolbarDelegate
