@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2017 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2018 Savoir-faire Linux Inc.
  *
  *  Author: Alexandre Bourget <alexandre.bourget@savoirfairelinux.com>
  *  Author: Yan Morin <yan.morin@savoirfairelinux.com>
@@ -30,10 +30,10 @@
 #include "config.h"
 #endif
 
-#include "logger.h"
 #include "manager.h"
+
+#include "logger.h"
 #include "account_schema.h"
-#include "plugin_manager.h"
 #include "thread_pool.h"
 
 #include "fileutils.h"
@@ -61,7 +61,6 @@ using random_device = dht::crypto::random_device;
 #include "audio/sound/tonelist.h"
 #include "audio/sound/dtmf.h"
 #include "audio/ringbufferpool.h"
-#include "manager.h"
 
 #ifdef RING_VIDEO
 #include "client/videomanager.h"
@@ -79,6 +78,8 @@ using random_device = dht::crypto::random_device;
 #include "video/sinkclient.h"
 #include "audio/tonecontrol.h"
 
+#include "data_transfer.h"
+
 #include <cerrno>
 #include <ctime>
 #include <cstdlib>
@@ -186,11 +187,16 @@ setSipLogLevel()
         // From 0 (min) to 6 (max)
         level = std::max(0, std::min(level, 6));
     }
+#else
+    int level = 0;
+#endif
 
     pj_log_set_level(level);
-#else
-    pj_log_set_level(0);
-#endif
+    pj_log_set_log_func([](int level, const char *data, int /*len*/) {
+        if      (level < 2) RING_ERR() << data;
+        else if (level < 4) RING_WARN() << data;
+        else                RING_DBG() << data;
+    });
 }
 
 /**
@@ -347,8 +353,6 @@ struct Manager::ManagerPimpl
      */
     std::unique_ptr<RingBufferPool> ringbufferpool_;
 
-    std::unique_ptr<PluginManager> pluginManager_;
-
     std::map<uintptr_t, Manager::EventHandler> eventHandlerMap_;
 
     decltype(eventHandlerMap_)::iterator nextEventHandler_;
@@ -386,7 +390,6 @@ Manager::ManagerPimpl::ManagerPimpl(Manager& base)
     , waitingCallsMutex_()
     , path_()
     , ringbufferpool_(new RingBufferPool)
-    , pluginManager_(new PluginManager)
     , conferenceMap_()
     , ice_tf_()
 #ifdef RING_VIDEO
@@ -662,6 +665,7 @@ Manager::Manager()
 #endif
     , callFactory()
     , accountFactory()
+    , dataTransfers(std::make_unique<DataTransferFacade>())
     , pimpl_ (new ManagerPimpl(*this))
 {}
 
@@ -841,25 +845,25 @@ Manager::unregisterAccounts()
 /* Main Thread */
 
 std::string
-Manager::outgoingCall(const std::string& preferred_account_id,
+Manager::outgoingCall(const std::string& account_id,
                           const std::string& to,
-                          const std::string& conf_id)
+                          const std::string& conf_id,
+                          const std::map<std::string, std::string>& volatileCallDetails)
 {
     if (not conf_id.empty() and not isConference(conf_id)) {
         RING_ERR("outgoingCall() failed, invalid conference id");
         return {};
     }
 
+    RING_DBG() << "try outgoing call to '" << to << "'"
+               << " with account '" << account_id << "'";
+
     std::string current_call_id(getCurrentCallId());
     std::string to_cleaned = hookPreference.getNumberAddPrefix() + trim(to);
     std::shared_ptr<Call> call;
 
     try {
-        /* RING_WARN: after this call the account_id is obsolete
-         * as the factory may decide to use another account (like IP2IP).
-         */
-        RING_DBG("New outgoing call to %s", to_cleaned.c_str());
-        call = newOutgoingCall(to_cleaned, preferred_account_id);
+        call = newOutgoingCall(to_cleaned, account_id, volatileCallDetails);
     } catch (const std::exception &e) {
         RING_ERR("%s", e.what());
         return {};
@@ -1146,7 +1150,7 @@ Manager::transferFailed()
 void
 Manager::transferSucceeded()
 {
-    transferSucceeded();
+    emitSignal<DRing::CallSignal::TransferSucceeded>();
 }
 
 bool
@@ -1456,9 +1460,6 @@ Manager::joinParticipant(const std::string& callId1, const std::string& callId2)
     pimpl_->switchCall(conf->getConfID());
     conf->setState(Conference::ACTIVE_ATTACHED);
 
-    // set recording sampling rate
-    conf->setRecordingAudioFormat(pimpl_->ringbufferpool_->getInternalAudioFormat());
-
     pimpl_->conferenceMap_.insert(std::make_pair(conf->getConfID(), conf));
     emitSignal<DRing::CallSignal::ConferenceCreated>(conf->getConfID());
     return true;
@@ -1500,7 +1501,6 @@ Manager::createConfFromParticipantList(const std::vector< std::string > &partici
     if (successCounter >= 2) {
         pimpl_->conferenceMap_[conf->getConfID()] = conf;
         emitSignal<DRing::CallSignal::ConferenceCreated>(conf->getConfID());
-        conf->setRecordingAudioFormat(pimpl_->ringbufferpool_->getInternalAudioFormat());
     }
 }
 
@@ -1679,7 +1679,7 @@ Manager::unregisterEventHandler(uintptr_t handlerId)
 }
 
 void
-Manager::addTask(const std::function<bool()>&& task)
+Manager::addTask(std::function<bool()>&& task)
 {
     std::lock_guard<std::mutex> lock(pimpl_->scheduledTasksMutex_);
     pimpl_->pendingTaskList_.emplace_back(std::move(task));
@@ -1919,8 +1919,36 @@ Manager::incomingCall(Call &call, const std::string& accountId)
 
     emitSignal<DRing::CallSignal::IncomingCall>(accountId, callID, call.getPeerDisplayName() + " " + from);
 
-    if (pimpl_->autoAnswer_)
+    auto currentCall = getCurrentCall();
+    if (pimpl_->autoAnswer_) {
         runOnMainThread([this, callID]{ answerCall(callID); });
+    } else if (currentCall) {
+        // Test if already calling this person
+        if (currentCall->getAccountId() == accountId
+        && currentCall->getPeerNumber() == call.getPeerNumber()) {
+            auto device_uid = currentCall->getAccount().getUsername();
+            if (device_uid.find("ring:") == 0) {
+                // NOTE: in case of a SIP call it's already ready to compare
+                device_uid = device_uid.substr(5); // after ring:
+            }
+            auto answerToCall = false;
+            auto downgradeToAudioOnly = currentCall->isAudioOnly() != call.isAudioOnly();
+            if (downgradeToAudioOnly)
+                // Accept the incoming audio only
+                answerToCall = call.isAudioOnly();
+            else
+                // Accept the incoming call from the higher id number
+                answerToCall = (device_uid.compare(call.getPeerNumber()) < 0);
+
+            if (answerToCall) {
+                auto currentCallID = currentCall->getCallId();
+                runOnMainThread([this, currentCallID, callID] {
+                    answerCall(callID);
+                    hangupCall(currentCallID);
+                });
+            }
+        }
+    }
 }
 
 void
@@ -2375,7 +2403,7 @@ Manager::toggleRecordingCall(const std::string& id)
     }
 
     const bool result = rec->toggleRecording();
-    emitSignal<DRing::CallSignal::RecordPlaybackFilepath>(id, rec->getAudioFilename());
+    emitSignal<DRing::CallSignal::RecordPlaybackFilepath>(id, rec->getPath());
     emitSignal<DRing::CallSignal::RecordingStateChanged>(id, result);
     return result;
 }
@@ -2414,11 +2442,9 @@ Manager::recordingPlaybackSeek(const double value)
 }
 
 void
-Manager::stopRecordedFilePlayback(const std::string& filepath)
+Manager::stopRecordedFilePlayback()
 {
-    // TODO: argument is uneeded (API change)
-
-    RING_DBG("Stop recorded file playback %s", filepath.c_str());
+    RING_DBG("Stop recorded file playback");
 
     checkAudio();
     pimpl_->toneCtrl_.stopAudioFile();
@@ -2655,8 +2681,7 @@ Manager::setAccountDetails(const std::string& accountID,
             account->doUnregister();
 
         // Update account details to the client side
-        emitSignal<DRing::ConfigurationSignal::VolatileDetailsChanged>(accountID,
-                                                                       details);
+        emitSignal<DRing::ConfigurationSignal::AccountDetailsChanged>(accountID, details);
     });
 }
 
@@ -2858,9 +2883,7 @@ Manager::getConferenceDetails(
 std::vector<std::string>
 Manager::getConferenceList() const
 {
-    std::vector<std::string> v;
-    map_utils::vectorFromMapKeys(pimpl_->conferenceMap_, v);
-    return v;
+    return map_utils::extractKeys(pimpl_->conferenceMap_);
 }
 
 std::vector<std::string>
@@ -3002,6 +3025,9 @@ Manager::setAccountActive(const std::string& accountID, bool active)
         else
             acc->doUnregister();
     }
+    emitSignal<DRing::ConfigurationSignal::VolatileDetailsChanged>(
+        accountID,
+        acc->getVolatileAccountDetails());
 }
 
 std::shared_ptr<AudioLayer>
@@ -3011,40 +3037,17 @@ Manager::getAudioDriver()
 }
 
 std::shared_ptr<Call>
-Manager::newOutgoingCall(const std::string& toUrl, const std::string& preferredAccountId)
+Manager::newOutgoingCall(const std::string& toUrl,
+                         const std::string& accountId,
+                         const std::map<std::string, std::string>& volatileCallDetails)
 {
-    auto account = getAccount(preferredAccountId);
+    auto account = getAccount(accountId);
     if (account and !account->isUsable()) {
-        RING_WARN("Prefered account is not usable for calling");
-        account = nullptr;
-    }
-
-    // If no prefered or not suitable account given,
-    // find first usable account depending on url scheme.
-    if (toUrl.find("ring:") != std::string::npos) {
-        if (!account or account->getAccountType() != RingAccount::ACCOUNT_TYPE) {
-            account = findAccount<RingAccount>([](const std::shared_ptr<RingAccount>& acc){
-                                                   return acc->isUsable();
-                                               });
-        }
-    } else if (!account or account->getAccountType() != SIPAccount::ACCOUNT_TYPE) {
-        // For IP url restricts results on IP2IP accounts
-        auto strippedToUrl = toUrl;
-        sip_utils::stripSipUriPrefix(strippedToUrl);
-        auto only_ip = IpAddr::isValid(strippedToUrl);
-
-        account = findAccount<SIPAccount>([only_ip](const std::shared_ptr<SIPAccount>& acc) {
-                                              return acc->isUsable()
-                                                  and (!only_ip or acc->isIP2IP());
-                                          });
-    }
-
-    if (!account) {
-        RING_ERR("No suitable account to create outgoing call");
+        RING_WARN("Account is not usable for calling");
         return nullptr;
     }
 
-    return account->newOutgoingCall(toUrl);
+    return account->newOutgoingCall(toUrl, volatileCallDetails);
 }
 
 #ifdef RING_VIDEO
@@ -3119,4 +3122,12 @@ Manager::getVideoManager() const
 }
 #endif
 
+std::vector<DRing::Message>
+Manager::getLastMessages(const std::string& accountID, const uint64_t& base_timestamp)
+{
+    if (const auto acc = getAccount(accountID))
+        return acc->getLastMessages(base_timestamp);
+    return {};
+}
+
 } // namespace ring
