@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2013-2017 Savoir-faire Linux Inc.
+ *  Copyright (C) 2013-2018 Savoir-faire Linux Inc.
  *
  *  Author: Guillaume Roguez <Guillaume.Roguez@savoirfairelinux.com>
  *
@@ -21,13 +21,20 @@
 
 #include "config.h"
 
+#include "rational.h"
+
 #ifdef RING_VIDEO
 #include "video/video_base.h"
 #include "video/video_scaler.h"
 #endif // RING_VIDEO
 
+#ifdef RING_ACCEL
+#include "video/accel.h"
+#endif
+
 #include "audio/audiobuffer.h"
 
+#include "media_stream.h"
 #include "rational.h"
 #include "noncopyable.h"
 
@@ -36,22 +43,17 @@
 #include <memory>
 #include <chrono>
 
-class AVCodecContext;
-class AVStream;
-class AVDictionary;
-class AVFormatContext;
-class AVCodec;
+struct AVCodecContext;
+struct AVStream;
+struct AVDictionary;
+struct AVFormatContext;
+struct AVCodec;
+enum AVMediaType;
 
 namespace ring {
 
-#ifdef RING_ACCEL
-namespace video {
-class HardwareAccel;
-}
-#endif
-
 struct AudioFrame;
-class AudioFormat;
+struct AudioFormat;
 class RingBuffer;
 class Resampler;
 class MediaIOHandle;
@@ -95,9 +97,11 @@ class MediaDecoder {
 
         void setOptions(const std::map<std::string, std::string>& options);
 #ifdef RING_ACCEL
-        void enableAccel(const bool enableAccel) { enableAccel_ = enableAccel; }
+        void enableAccel(bool enableAccel);
 #endif
 
+        MediaStream getStream() const;
+
     private:
         NON_COPYABLE(MediaDecoder);
 
@@ -111,16 +115,21 @@ class MediaDecoder {
         int streamIndex_ = -1;
         bool emulateRate_ = false;
         int64_t startTime_;
+        int64_t lastTimestamp_;
 
         AudioBuffer decBuff_;
         AudioBuffer resamplingBuff_;
 
         void extract(const std::map<std::string, std::string>& map, const std::string& key);
         int correctPixFmt(int input_pix_fmt);
+        int setupStream(AVMediaType mediaType);
+
+        bool fallback_ = false;
 
 #ifdef RING_ACCEL
         bool enableAccel_ = true;
-        std::unique_ptr<video::HardwareAccel> accel_;
+        video::HardwareAccel accel_;
+        unsigned short accelFailures_ = 0;
 #endif
 
     protected:
