@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004-2017 Savoir-faire Linux Inc.
+ *  Copyright (C) 2004-2018 Savoir-faire Linux Inc.
  *
  *  Author: Emmanuel Milou <emmanuel.milou@savoirfairelinux.com>
  *  Author: Yun Liu <yun.liu@savoirfairelinux.com>
@@ -273,7 +273,16 @@ transaction_request_cb(pjsip_rx_data *rdata)
 
     Manager::instance().hookPreference.runHook(rdata->msg_info.msg);
 
-    auto call = account->newIncomingCall(remote_user);
+    bool hasVideo = false;
+    if (r_sdp) {
+        auto pj_str_video = pj_str((char*) "video");
+        for (decltype(r_sdp->media_count) i=0 ; i < r_sdp->media_count; i++) {
+            if (pj_strcmp(&r_sdp->media[i]->desc.media, &pj_str_video) == 0)
+                hasVideo = true;
+        }
+    }
+
+    auto call = account->newIncomingCall(remote_user, {{"AUDIO_ONLY", (hasVideo ? "false" : "true") }});
     if (!call) {
         return PJ_FALSE;
     }
@@ -284,7 +293,7 @@ transaction_request_cb(pjsip_rx_data *rdata)
     // Append PJSIP transport to the broker's SipTransport list
     auto transport = link->sipTransportBroker->addTransport(rdata->tp_info.transport);
     if (!transport) {
-        if (account->getAccountType() == SIPAccount::ACCOUNT_TYPE) {
+        if (not ::strcmp(account->getAccountType(), SIPAccount::ACCOUNT_TYPE)) {
             RING_WARN("Using transport from account.");
             transport = std::static_pointer_cast<SIPAccount>(account)->getTransport();
         }
@@ -322,10 +331,10 @@ transaction_request_cb(pjsip_rx_data *rdata)
         }
     }
 
-    call->setState(Call::ConnectionState::PROGRESSING);
     call->setPeerNumber(peerNumber);
+    call->setPeerUri(account->getToUri(peerNumber));
     call->setPeerDisplayName(peerDisplayName);
-    call->initRecFilename(peerNumber);
+    call->setState(Call::ConnectionState::PROGRESSING);
     call->getSDP().setPublishedIP(addrSdp);
 
     if (account->isStunEnabled())
@@ -333,7 +342,7 @@ transaction_request_cb(pjsip_rx_data *rdata)
 
     call->getSDP().receiveOffer(r_sdp,
         account->getActiveAccountCodecInfoList(MEDIA_AUDIO),
-        account->getActiveAccountCodecInfoList(account->isVideoEnabled() ? MEDIA_VIDEO : MEDIA_NONE),
+        account->getActiveAccountCodecInfoList(account->isVideoEnabled() and hasVideo ? MEDIA_VIDEO : MEDIA_NONE),
         account->getSrtpKeyExchange());
     call->setRemoteSdp(r_sdp);
 
@@ -434,7 +443,6 @@ transaction_request_cb(pjsip_rx_data *rdata)
             replacedCall->hangup(PJSIP_SC_OK);
     }
 
-
     return PJ_FALSE;
 }
 
@@ -495,16 +503,29 @@ SIPVoIPLink::SIPVoIPLink() : pool_(nullptr, pj_pool_release)
     auto ns = ip_utils::getLocalNameservers();
     if (not ns.empty()) {
         std::vector<pj_str_t> dns_nameservers(ns.size());
+        std::vector<pj_uint16_t> dns_ports(ns.size());
         for (unsigned i=0, n=ns.size(); i<n; i++) {
             char hbuf[NI_MAXHOST];
-            getnameinfo((sockaddr*)&ns[i], ns[i].getLength(), hbuf, sizeof(hbuf), nullptr, 0, NI_NUMERICHOST);
-            RING_DBG("Using SIP nameserver: %s", hbuf);
-            pj_strdup2(pool_.get(), &dns_nameservers[i], hbuf);
+            if (auto ret = getnameinfo((sockaddr*)&ns[i], ns[i].getLength(), hbuf, sizeof(hbuf), nullptr, 0, NI_NUMERICHOST)) {
+                RING_WARN("Error printing SIP nameserver: %s", strerror(ret));
+            } else {
+                RING_DBG("Using SIP nameserver: %s", hbuf);
+                pj_strdup2(pool_.get(), &dns_nameservers[i], hbuf);
+                dns_ports[i] = ns[i].getPort();
+            }
         }
         pj_dns_resolver* resv;
-        TRY(pjsip_endpt_create_resolver(endpt_, &resv));
-        TRY(pj_dns_resolver_set_ns(resv, ns.size(), dns_nameservers.data(), nullptr));
-        TRY(pjsip_endpt_set_resolver(endpt_, resv));
+        if (auto ret = pjsip_endpt_create_resolver(endpt_, &resv)) {
+            RING_WARN("Error creating SIP DNS resolver: %s", sip_utils::sip_strerror(ret).c_str());
+        } else {
+            if (auto ret = pj_dns_resolver_set_ns(resv, dns_nameservers.size(), dns_nameservers.data(), dns_ports.data())) {
+                RING_WARN("Error setting SIP DNS servers: %s", sip_utils::sip_strerror(ret).c_str());
+            } else {
+                if (auto ret = pjsip_endpt_set_resolver(endpt_, resv)) {
+                    RING_WARN("Error setting pjsip DNS resolver: %s", sip_utils::sip_strerror(ret).c_str());
+                }
+            }
+        }
     }
 
     sipTransportBroker.reset(new SipTransportBroker(endpt_, cp_, *pool_));
@@ -542,6 +563,9 @@ SIPVoIPLink::SIPVoIPLink() : pool_(nullptr, pj_pool_release)
         outgoing_request_forked_cb,
         transaction_state_changed_cb,
         sdp_request_offer_cb,
+#if PJ_VERSION_NUM >= (2 << 24 | 7 << 16)
+        nullptr /* on_rx_offer2 */,
+#endif
 #if PJ_VERSION_NUM > (2 << 24 | 1 << 16)
         nullptr /* on_rx_reinvite */,
 #endif
@@ -824,7 +848,8 @@ invite_session_state_changed_cb(pjsip_inv_session *inv, pjsip_event *ev)
                     if (inv->role != PJSIP_ROLE_UAC)
                         break;
                     // close call
-
+                    call->onClosed();
+                    break;
                 // The call terminates normally - BYE / CANCEL
                 case PJSIP_SC_OK:
                 case PJSIP_SC_REQUEST_TERMINATED:
@@ -896,19 +921,6 @@ sdp_create_offer_cb(pjsip_inv_session *inv, pjmedia_sdp_session **p_offer)
         *p_offer = localSDP.getLocalSdpSession();
 }
 
-static void
-dump_sdp_session(const pjmedia_sdp_session* sdp_session, const char* header)
-{
-    char buffer[4096] {};
-
-    if (pjmedia_sdp_print(sdp_session, buffer, sizeof buffer) == -1) {
-        RING_ERR("%sSDP too big for dump", header);
-        return;
-    }
-
-    RING_DBG("%s%s", header, buffer);
-}
-
 static const pjmedia_sdp_session*
 get_active_remote_sdp(pjsip_inv_session *inv)
 {
@@ -924,7 +936,7 @@ get_active_remote_sdp(pjsip_inv_session *inv)
         return nullptr;
     }
 
-    dump_sdp_session(sdp_session, "Remote active SDP Session:\n");
+    Sdp::printSession(sdp_session, "Remote active SDP Session:\n");
     return sdp_session;
 }
 
@@ -943,7 +955,7 @@ get_active_local_sdp(pjsip_inv_session *inv)
         return nullptr;
     }
 
-    dump_sdp_session(sdp_session, "Local active SDP Session:\n");
+    Sdp::printSession(sdp_session, "Local active SDP Session:\n");
     return sdp_session;
 }
 
@@ -1240,11 +1252,11 @@ SIPVoIPLink::resolveSrvName(const std::string &name, pjsip_transport_type_e type
     pjsip_endpt_resolve(endpt_, pool_.get(), &host_info, (void*)token, resolver_callback);
 }
 
-#define RETURN_IF_NULL(A, M, ...) \
-    if ((A) == NULL) { RING_WARN(M, ##__VA_ARGS__); return; }
+#define RETURN_IF_NULL(A, ...) \
+    if ((A) == NULL) { RING_WARN(__VA_ARGS__); return; }
 
-#define RETURN_FALSE_IF_NULL(A, M, ...) \
-    if ((A) == NULL) { RING_WARN(M, ##__VA_ARGS__); return false; }
+#define RETURN_FALSE_IF_NULL(A, ...) \
+    if ((A) == NULL) { RING_WARN(__VA_ARGS__); return false; }
 
 void
 SIPVoIPLink::findLocalAddressFromTransport(pjsip_transport* transport,
@@ -1322,7 +1334,11 @@ SIPVoIPLink::findLocalAddressFromSTUN(pjsip_transport* transport,
 
     pj_sockaddr_in mapped_addr;
     pj_sock_t sipSocket = pjsip_udp_transport_get_socket(transport);
-    const pjstun_setting stunOpt = {PJ_TRUE, *stunServerName, stunPort,
+    const pjstun_setting stunOpt = {PJ_TRUE,
+#if PJ_VERSION_NUM > (2 << 24 | 7 << 16)
+                                    localIp.getFamily(),
+#endif
+                                    *stunServerName, stunPort,
                                     *stunServerName, stunPort};
     const pj_status_t stunStatus = pjstun_get_mapped_addr2(&cp_.factory,
                                                            &stunOpt, 1,
